Feedforward Closedloop Learning: Class Members

Feedforward Closedloop Learning

Here is a list of all documented class members with links to the class documentation for each member:

### - s -

- saveInitialWeights() : feedforward_closedloop_learning.Neuron , Neuron
- saveModel() : feedforward_closedloop_learning.FeedforwardClosedloopLearning , FeedforwardClosedloopLearning
- saveWeightMatrix() : feedforward_closedloop_learning.Layer , Layer
- seedRandom() : feedforward_closedloop_learning.FeedforwardClosedloopLearning , FeedforwardClosedloopLearning
- setActivationFunction() : feedforward_closedloop_learning.FeedforwardClosedloopLearning , feedforward_closedloop_learning.Layer , feedforward_closedloop_learning.Neuron , FeedforwardClosedloopLearning , Layer , Neuron
- setBias() : feedforward_closedloop_learning.FeedforwardClosedloopLearning , feedforward_closedloop_learning.Layer , feedforward_closedloop_learning.Neuron , FeedforwardClosedloopLearning , Layer , Neuron
- setBiasWeight() : feedforward_closedloop_learning.Neuron , Neuron
- setConvolution() : feedforward_closedloop_learning.Layer , Layer
- setDebugInfo() : feedforward_closedloop_learning.Layer , feedforward_closedloop_learning.Neuron , Layer , Neuron
- setDecay() : feedforward_closedloop_learning.FeedforwardClosedloopLearning , feedforward_closedloop_learning.Layer , feedforward_closedloop_learning.Neuron , FeedforwardClosedloopLearning , Layer , Neuron
- setError() : feedforward_closedloop_learning.Layer , feedforward_closedloop_learning.Neuron , Layer , Neuron
- setErrors() : feedforward_closedloop_learning.Layer , Layer
- setGeometry() : feedforward_closedloop_learning.Neuron , Neuron
- setInput() : feedforward_closedloop_learning.Layer , feedforward_closedloop_learning.Neuron , Layer , Neuron
- setInputs() : feedforward_closedloop_learning.Layer , Layer
- setLearningRate() : feedforward_closedloop_learning.FeedforwardClosedloopLearning , feedforward_closedloop_learning.Layer , feedforward_closedloop_learning.Neuron , FeedforwardClosedloopLearning , Layer , Neuron
- setLearningRateDiscountFactor() : feedforward_closedloop_learning.FeedforwardClosedloopLearning , FeedforwardClosedloopLearning
- setMask() : feedforward_closedloop_learning.Neuron , Neuron
- setMaxDetLayer() : feedforward_closedloop_learning.Layer , Layer
- setMomentum() : feedforward_closedloop_learning.FeedforwardClosedloopLearning , feedforward_closedloop_learning.Layer , feedforward_closedloop_learning.Neuron , FeedforwardClosedloopLearning , Layer , Neuron
- setNormaliseWeights() : feedforward_closedloop_learning.Layer , Layer
- setParameters() : Bandpass
- setStep() : feedforward_closedloop_learning.Layer , feedforward_closedloop_learning.Neuron , Layer , Neuron
- setUseThreads() : feedforward_closedloop_learning.Layer , Layer
- setWeight() : feedforward_closedloop_learning.Neuron , Neuron
- start() : feedforward_closedloop_learning.LayerThread